==> bootstrap-7.0.2.tgz: package/tsDist/components/dashboard/shared/Contributor/ContributorPresenter.js <==
import React from 'react';
import { ContributorCard } from './ContributorCard';
import { ContributorLoader } from './ContributorLoader';
import { GoToLink } from '../GoTo';
import { Header, WidgetTitle } from '../WidgetTitle';
import { Body, Column, ContributorBox, Message } from './styles';
export var ContributorPresenter = function (_a) {
    var title = _a.title, contributors = _a.contributors, aragoIdUrl = _a.aragoIdUrl, loading = _a.loading, error = _a.error, count = _a.count;
    return (React.createElement(ContributorBox, { centered: true },
        React.createElement(Header, null,
            React.createElement(WidgetTitle, null, title),
            React.createElement(GoToLink, { href: aragoIdUrl }, "Go to Arago ID")),
        React.createElement(Body, null, getWidgetContent({ contributors: contributors, error: error, loading: loading, count: count }))));
};
var getWidgetContent = function (_a) {
    var contributors = _a.contributors, error = _a.error, loading = _a.loading, count = _a.count;
    if (error) {
        return React.createElement(Message, null, "Something went wrong");
    }
    if (contributors.length === 0 && !loading) {
        return React.createElement(Message, null, "No contributors found");
    }
    if (loading) {
        return React.createElement(ContributorLoader, { count: count });
    }
    return contributors.map(function (rows, columnIndex) { return (React.createElement(Column, { key: columnIndex }, rows.map(function (_a) {
        var userId = _a.userId, ranking = _a.ranking, count = _a.count, avatarUrl = _a.avatarUrl;
        return (React.createElement(ContributorCard, { key: userId, userId: userId, ranking: ranking, count: count, avatarUrl: avatarUrl }));
    }))); });
};

==> bootstrap-7.0.15.tgz: package/tsDist/components/dashboard/shared/Contributor/ContributorPresenter.js <==
import React from 'react';
import { Box } from 'components/elements/Flex';
import { Header, WidgetTitle } from '../WidgetTitle';
// 7.0
// import { GoToLink } from '../GoTo';
import { ContributorCard } from './ContributorCard';
import { ContributorLoader } from './ContributorLoader';
import { Body, Column, Message } from './styles';
export var ContributorPresenter = function (_a) {
    var title = _a.title, contributors = _a.contributors, 
    // 7.0
    // aragoIdUrl,
    loading = _a.loading, error = _a.error, count = _a.count;
    return (React.createElement(Box, { centered: true },
        React.createElement(Header, null,
            React.createElement(WidgetTitle, null, title)),
        React.createElement(Body, null, getWidgetContent({ contributors: contributors, error: error, loading: loading, count: count }))));
};
var getWidgetContent = function (_a) {
    var contributors = _a.contributors, error = _a.error, loading = _a.loading, count = _a.count;
    if (error) {
        return React.createElement(Message, null, "Something went wrong");
    }
    if (contributors.length === 0 && !loading) {
        return React.createElement(Message, null, "No contributors found");
    }
    if (loading) {
        return React.createElement(ContributorLoader, { count: count });
    }
    return contributors.map(function (rows, columnIndex) { return (React.createElement(Column, { key: columnIndex }, rows.map(function (_a) {
        var userId = _a.userId, ranking = _a.ranking, count = _a.count, avatarUrl = _a.avatarUrl;
        return (React.createElement(ContributorCard, { key: userId, userId: userId, ranking: ranking, count: count, avatarUrl: avatarUrl }));
    }))); });
};
